@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Project Hamster.  If not, see <http://www.gnu.org/licenses/>.
 
-from hamster.stuff import format_duration, figure_time
+from stuff import format_duration, figure_time
 import gtk
 import datetime as dt
 import calendar
@@ -362,4 +362,4 @@ class TimeInput(gtk.Entry):
         self.popup.show()
 
 
-    
\ No newline at end of file
+    
